%define name        bouncycastle
%define version     1.20
%define archivever  120
%define release     2jpp

%define section     free

Summary:        Bouncy Castle Crypto Package for Java
Name:           %{name}
Version:        %{version}
Release:        %{release}
Epoch:          0
Group:          Security/Cryptography
License:        Bouncy Castle License
URL:            http://www.%{name}.org/
BuildArch:      noarch
Source0:        ftp://ftp.bouncycastle.org/pub/release1.20/bcmail-jdk13-120.tar.gz
Source1:        ftp://ftp.bouncycastle.org/pub/release1.20/bcmail-jdk14-120.tar.gz
Source2:        ftp://ftp.bouncycastle.org/pub/release1.20/bcpg-jdk13-120.tar.gz
Source3:        ftp://ftp.bouncycastle.org/pub/release1.20/bcpg-jdk14-120.tar.gz
Source4:        ftp://ftp.bouncycastle.org/pub/release1.20/bcprov-jdk14-120.tar.gz
Source5:        ftp://ftp.bouncycastle.org/pub/release1.20/jce-jdk13-120.tar.gz
Source6:        ftp://ftp.bouncycastle.org/pub/release1.20/lcrypto-jdk13-120.tar.gz
Source7:        ftp://ftp.bouncycastle.org/pub/release1.20/lcrypto-jdk14-120.tar.gz
# FIXME: Just sign the jar
# We keep original 1.4 provider since java 1.4 wants it to be signed
# This sucks big time - should we add jar signing infrastructure to
# jpackage in // to rpm signing? Sun seems much less user-friendly than
# your average Linux distribution
Source8:	ftp://ftp.bouncycastle.org/pub/release1.20/bcprov-jdk14-120.jar
NoSource:       0
NoSource:	1
NoSource:	2
NoSource:	3
NoSource:	4
NoSource:	5
NoSource:	6
NoSource:	7
NoSource:	8
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root
Vendor:         JPackage Project
Distribution:   JPackage
Requires:       %{name}-provider = %{epoch}:%{version}-%{release}
Requires:       jpackage-utils >= 0:1.5
BuildRequires:  junit, jaf, javamail, sed, findutils
BuildRequires:	java-devel >= 0:1.4.0
BuildRequires:	jpackage-utils >= 0:1.5

%description
The Bouncy Castle Crypto APIs consist of the following:
- A lightweight cryptography API in Java.
- A provider for the JCE and JCA.
- A clean room implementation of the JCE 1.2.1.
- Generators for Version 1 and Version 3 X.509 certificates and PKCS12 files.
- A signed jar version suitable for JDK 1.4 and the Sun JCE.

%package jdk1.3
Group:          Security/Cryptography
Summary:        Bouncy Castle JCE APIs for Java 1.3.x
Requires:       %{name} = %{epoch}:%{version}-%{release}, jaf, javamail
Requires:	java < 0:1.4.0
BuildRequires:	java-devel < 0:1.4.0
Provides:	%{name}-provider = %{epoch}:%{version}-%{release}
Requires:       /usr/sbin/update-alternatives
Provides:       jce = 0:1.2.1
Conflicts:	jce-ext < 0:1.2.2-5jpp

%description jdk1.3
Bouncy Castle JCE APIs for Java 1.3.

%package jdk1.4
Group:          Security/Cryptography
Summary:        Bouncy Castle JCE APIs for Java 1.4.x
Requires:       %{name} = %{epoch}:%{version}-%{release}, jaf, javamail
Requires:	java >= 0:1.4.0
BuildRequires:	java-devel >= 0:1.4.0
Provides:	%{name}-provider = %{epoch}:%{version}-%{release}

%description jdk1.4
Bouncy Castle JCE APIs for Java 1.4.

%package javadoc-jdk1.3
Group:          Documentation
Summary:        Java 1.3 javadoc for %{name}

%description javadoc-jdk1.3
Java 1.3 javadoc for %{name}.

%package javadoc-jdk1.4
Group:          Documentation
Summary:        Java 1.4 javadoc for %{name}

%description javadoc-jdk1.4
Java 1.4 javadoc for %{name}.

%prep
%setup -q -c -D -T -a 0
%setup -q -D -T -a 1
%setup -q -D -T -a 2
%setup -q -D -T -a 3
%setup -q -D -T -a 4
%setup -q -D -T -a 5
%setup -q -D -T -a 6
%setup -q -D -T -a 7

# Remove provided binaries
find . -type f -name "*.jar" -exec rm -f {} \;
find . -type f -name "*.class" -exec rm -f {} \;
find . -type f -name "*.zip" -exec rm -f {} \;

%build
# 1.3
deps="junit javamail/mailapi jaf jce"
dirs1="jce-jdk13-%{archivever} bcmail-jdk13-%{archivever} bcpg-jdk13-%{archivever} lcrypto-jdk13-%{archivever}"

unset JAVA_HOME
for javaver in 1.3.0 1.3.1; do
   [ -d "%{_jvmdir}/java-${javaver}" ] && \
   export JAVA_HOME=%{_jvmdir}/java-${javaver}
done
[ -z "$JAVA_HOME" ] && exit 1

export CLASSPATH=$(build-classpath $deps):$RPM_BUILD_DIR/%{name}-%{version}/jce-jdk13-%{archivever}/jce-jdk13-%{version}.jar:.

javac=$JAVA_HOME/bin/javac
jar=$JAVA_HOME/bin/jar
javadoc=$JAVA_HOME/bin/javadoc

for i in $dirs1; do
	pushd $i/src
	rm -rf docs/*
	# FIXME: These should go in separate jars instead of being deleted
	find . -type d -name examples | xargs rm -rf
	find . -type d -name test | xargs rm -rf
	$javac `find . -type f -name "*.java"`
	jar2="../`basename $i -%{archivever}`-%{version}.jar"
        files="`find . -type f -name "*.class"`"
        test ! -d classes && mf="" || mf="`find classes -type f -name "*.mf" 2>/dev/null`"
	test -n "$mf" && $jar cvfm $jar2 $mf $files || $jar cvf $jar2 $files
	popd
done

# 1.4
deps="junit javamail/mailapi jaf"
dirs2="bcprov-jdk14-%{archivever} bcmail-jdk14-%{archivever} bcpg-jdk14-%{archivever} lcrypto-jdk14-%{archivever}"

unset JAVA_HOME
for javaver in 1.4.0 1.4.1 1.4.2; do
   [ -d "%{_jvmdir}/java-${javaver}" ] && \
   export JAVA_HOME=%{_jvmdir}/java-${javaver}
done
[ -z "$JAVA_HOME" ] && exit

export CLASSPATH=$(build-classpath $deps):$RPM_BUILD_DIR/%{name}-%{version}/bcprov-jdk14-%{archivever}/bcprov-jdk14-%{version}.jar:.

javac=$JAVA_HOME/bin/javac
jar=$JAVA_HOME/bin/jar
javadoc=$JAVA_HOME/bin/javadoc

for i in $dirs2; do
	pushd $i/src
	rm -rf docs/*
	# FIXME: These should go in separate jars instead of being deleted
	find . -type d -name examples | xargs rm -rf
	find . -type d -name test | xargs rm -rf
	$javac `find . -type f -name "*.java"`
	jar2="../`basename $i -%{archivever}`-%{version}.jar"
        files="`find . -type f -name "*.class"`"
        test ! -d classes && mf="" || mf="`find classes/ -type f -name "*.mf" 2>/dev/null`"
	test -n "$mf" && $jar cvfm $jar2 $mf $files || $jar cvf $jar2 $files
	popd
done


# 1.3 and 1.4 javadocs
dirs="$dirs1 $dirs2"

for i in $dirs; do
	pushd $i
	for j in *.html; do
		mv -f $j $i-$j
	done

	mv -f *.html ../

	$javadoc -d docs `find . -type f -name "*.class"` || :
	popd
done

%install
rm -rf $RPM_BUILD_ROOT

# jars
jars=`find . -type f -name "*.jar"`

for i in $jars; do
	mv -f $i .
done

# Replace built 1.4 provider with original one
rm -f bcprov-jdk14-%{version}.jar
cp -f %{SOURCE8} bcprov-jdk14-%{version}.jar

# Java 1.3
install -m 0755 -d $RPM_BUILD_ROOT%{_javadir}-{ext/%{name}-jdk1.3,1.3.0,1.3.1}

for jar13 in *-jdk13-%{version}.jar; do
   jar=$(echo $jar13 | sed s+-jdk13++g)
   install -m 0644 $jar13 $RPM_BUILD_ROOT%{_javadir}-ext/%{name}-jdk1.3/$jar
done

pushd $RPM_BUILD_ROOT%{_javadir}-ext/%{name}-jdk1.3
   for jar in *-%{version}.jar; do
      ln -sf $jar $(echo $jar | sed s+-%{version}\.jar+.jar+g)
   done
popd

for javaver in 1.3.0 1.3.1; do
   # FIXME: This should be relative
   (cd $RPM_BUILD_ROOT/%{_javadir}-${javaver} && ln -sf %{_javadir}-ext/%{name}-jdk1.3 %{name})
done

# Java 1.4
install -m 0755 -d $RPM_BUILD_ROOT%{_javadir}-{ext/%{name}-jdk1.4,1.4.0,1.4.1,1.4.2}

for jar14 in *-jdk14-%{version}.jar; do
   jar=$(echo $jar14 | sed s+-jdk14++g)
   install -m 0644 $jar14 $RPM_BUILD_ROOT%{_javadir}-ext/%{name}-jdk1.4/$jar
done

pushd $RPM_BUILD_ROOT%{_javadir}-ext/%{name}-jdk1.4
   for jar in *-%{version}.jar; do
      ln -sf $jar $(echo $jar | sed s+-%{version}\.jar+.jar+g)
   done
popd

for javaver in 1.4.0 1.4.1 1.4.2; do
   # FIXME: This should be relative
   (cd $RPM_BUILD_ROOT/%{_javadir}-${javaver} && ln -sf %{_javadir}-ext/%{name}-jdk1.4 %{name})
done

# javadoc
install -m 0755 -d $RPM_BUILD_ROOT%{_javadocdir}/%{name}-{jdk13,jdk14}-%{version}
(cd $RPM_BUILD_ROOT%{_javadocdir} && ln -sf %{name}-jdk13-%{version} %{name}-jdk13)
(cd $RPM_BUILD_ROOT%{_javadocdir} && ln -sf %{name}-jdk14-%{version} %{name}-jdk14)

for javaver in 13 14; do
   for javadoc in $(find . -type d -name docs | grep jdk${javaver}); do
      dest=$(echo $javadoc | sed s+-jdk${javaver}-%{version}++g |sed s+/docs++g)
      cp -pr $javadoc $RPM_BUILD_ROOT%{_javadocdir}/%{name}-jdk${javaver}-%{version}/$dest
   done
done

find . -type d -name docs | xargs rm -rf

%post jdk1.3

for javaver in 1.3.0 1.3.1; do
   update-alternatives \
      --install %{_javadir}-${javaver}/jce.jar jce_${javaver} %{_javadir}-ext/%{name}-jdk1.3/jce.jar 0
done

%postun jdk1.3
[ "$1" = "0" ] || exit 0
for javaver in 1.3.0 1.3.1; do
   update-alternatives --remove jce_${javaver} %{_javadir}-ext/%{name}-jdk1.3/jce.jar
done


%clean
rm -rf $RPM_BUILD_ROOT

%post javadoc-jdk1.3
rm -f %{_javadocdir}/%{name}-jdk13
ln -s %{name}-jdk13-%{version} %{_javadocdir}/%{name}-jdk13

%postun javadoc-jdk1.3
if [ $1 -eq 0 ]; then
  rm -f %{_javadocdir}/%{name}-jdk13
fi

%post javadoc-jdk1.4
rm -f %{_javadocdir}/%{name}-jdk14
ln -s %{name}-jdk14-%{version} %{_javadocdir}/%{name}-jdk14

%postun javadoc-jdk1.4
if [ $1 -eq 0 ]; then
  rm -f %{_javadocdir}/%{name}-jdk1.4
fi

%files
%defattr(0644,root,root,0755)
%doc *.html

%files jdk1.3
%defattr(0644,root,root,0755)
%dir %{_javadir}-ext/%{name}-jdk1.3
%{_javadir}-ext/%{name}-jdk1.3/*.jar
%{_javadir}-1.3.0/%{name}
%{_javadir}-1.3.1/%{name}

%files jdk1.4
%defattr(0644,root,root,0755)
%dir %{_javadir}-ext/%{name}-jdk1.4
%{_javadir}-ext/%{name}-jdk1.4/*.jar
%{_javadir}-1.4.0/%{name}
%{_javadir}-1.4.1/%{name}
%{_javadir}-1.4.2/%{name}

%files javadoc-jdk1.3
%defattr(0644,root,root,0755)
%dir %{_javadocdir}/%{name}-jdk13-%{version}
%{_javadocdir}/%{name}-jdk13-%{version}/*
%ghost %{_javadocdir}/%{name}-jdk13

%files javadoc-jdk1.4
%defattr(0644,root,root,0755)
%dir %{_javadocdir}/%{name}-jdk14-%{version}
%{_javadocdir}/%{name}-jdk14-%{version}/*
%ghost %{_javadocdir}/%{name}-jdk14

%changelog
* Fri Oct 10 2003 David Walluck <david@anti-microsoft.org> 0:1.20-2jpp
- fix javadoc symlinks

* Fri Oct 10 2003 David Walluck <david@anti-microsoft.org> 0:1.20-1jpp
- 1.20
- add epochs
- %%ghost symlinks
- maybe bouncycastle should consider using ant so that it
  doesn't take over three hours to script the build process
- oh, and maybe a single source archive, thanks

* Sun Sep 09 2003 David Walluck <david@anti-microsoft.org> 0:1.19-2jpp 
- build bcmail.jar for jdk1.4 package
- add Epoch
- Requires: jpackage-utils >= 0:1.5

* Fri Jun 27 2003 Nicolas Mailhot <Nicolas.Mailhot at laPoste.net> 1.19-1jpp
- First jpackage 1.5 release
- use upstream 1.4 binary due to Sun braindamage

* Sun Sep  8 2002 Ville Skytt <ville.skytta at iki.fi> 1.15-1jpp
- First JPackage release.

